#[repr(transparent)]pub struct PartialValidatorKey(pub FixedBytes<15>);Expand description
Partial validator public key encoded inside the nonce key.
Tuple Fields
0: FixedBytes<15>Implementations
Sourceimpl PartialValidatorKey
impl PartialValidatorKey
Sourcepub const ZERO: PartialValidatorKey
pub const ZERO: PartialValidatorKey
Array of Zero bytes.
Sourcepub const fn new(bytes: [u8; 15]) -> PartialValidatorKey
pub const fn new(bytes: [u8; 15]) -> PartialValidatorKey
Wraps the given byte array in this type.
Sourcepub const fn with_last_byte(x: u8) -> PartialValidatorKey
pub const fn with_last_byte(x: u8) -> PartialValidatorKey
Creates a new byte array with the last byte set to x.
Sourcepub const fn repeat_byte(byte: u8) -> PartialValidatorKey
pub const fn repeat_byte(byte: u8) -> PartialValidatorKey
Creates a new byte array where all bytes are set to byte.
Sourcepub fn random() -> PartialValidatorKey
pub fn random() -> PartialValidatorKey
Creates a new fixed byte array with the default cryptographic random number generator.
This is rand::thread_rng if the “rand” and “std” features are enabled, otherwise
it uses getrandom::getrandom. Both are cryptographically secure.
Sourcepub fn try_random() -> Result<PartialValidatorKey, Error>
pub fn try_random() -> Result<PartialValidatorKey, Error>
Tries to create a new fixed byte array with the default cryptographic random number generator.
See random for more details.
Sourcepub fn randomize(&mut self)
pub fn randomize(&mut self)
Fills this fixed byte array with the default cryptographic random number generator.
See random for more details.
Sourcepub fn try_randomize(&mut self) -> Result<(), Error>
pub fn try_randomize(&mut self) -> Result<(), Error>
Tries to fill this fixed byte array with the default cryptographic random number generator.
See random for more details.
Sourcepub fn random_with<R>(rng: &mut R) -> PartialValidatorKey
pub fn random_with<R>(rng: &mut R) -> PartialValidatorKey
Creates a new fixed byte array with the given random number generator.
Sourcepub fn try_random_with<R>(
rng: &mut R,
) -> Result<PartialValidatorKey, <R as TryRngCore>::Error>where
R: TryRngCore + ?Sized,
pub fn try_random_with<R>(
rng: &mut R,
) -> Result<PartialValidatorKey, <R as TryRngCore>::Error>where
R: TryRngCore + ?Sized,
Tries to create a new fixed byte array with the given random number generator.
Sourcepub fn randomize_with<R>(&mut self, rng: &mut R)
pub fn randomize_with<R>(&mut self, rng: &mut R)
Fills this fixed byte array with the given random number generator.
Sourcepub fn try_randomize_with<R>(
&mut self,
rng: &mut R,
) -> Result<(), <R as TryRngCore>::Error>where
R: TryRngCore + ?Sized,
pub fn try_randomize_with<R>(
&mut self,
rng: &mut R,
) -> Result<(), <R as TryRngCore>::Error>where
R: TryRngCore + ?Sized,
Tries to fill this fixed byte array with the given random number generator.
Sourcepub fn from_slice(src: &[u8]) -> PartialValidatorKey
pub fn from_slice(src: &[u8]) -> PartialValidatorKey
Sourcepub fn left_padding_from(value: &[u8]) -> PartialValidatorKey
pub fn left_padding_from(value: &[u8]) -> PartialValidatorKey
Sourcepub fn right_padding_from(value: &[u8]) -> PartialValidatorKey
pub fn right_padding_from(value: &[u8]) -> PartialValidatorKey
Sourcepub const fn into_array(self) -> [u8; 15]
pub const fn into_array(self) -> [u8; 15]
Returns the inner bytes array.
Sourcepub fn covers(&self, b: &PartialValidatorKey) -> bool
pub fn covers(&self, b: &PartialValidatorKey) -> bool
Returns true if all bits set in b are also set in self.
Sourcepub const fn const_eq(&self, other: &PartialValidatorKey) -> bool
pub const fn const_eq(&self, other: &PartialValidatorKey) -> bool
Compile-time equality. NOT constant-time equality.
Sourcepub const fn bit_and(self, rhs: PartialValidatorKey) -> PartialValidatorKey
pub const fn bit_and(self, rhs: PartialValidatorKey) -> PartialValidatorKey
Computes the bitwise AND of two FixedBytes.
Sourcepub const fn bit_or(self, rhs: PartialValidatorKey) -> PartialValidatorKey
pub const fn bit_or(self, rhs: PartialValidatorKey) -> PartialValidatorKey
Computes the bitwise OR of two FixedBytes.
Sourcepub const fn bit_xor(self, rhs: PartialValidatorKey) -> PartialValidatorKey
pub const fn bit_xor(self, rhs: PartialValidatorKey) -> PartialValidatorKey
Computes the bitwise XOR of two FixedBytes.
Methods from Deref<Target = FixedBytes<15>>
pub const ZERO: FixedBytes<N>
pub fn randomize(&mut self)
Available on crate feature getrandom only.
pub fn randomize(&mut self)
getrandom only.Fills this [FixedBytes] with the default cryptographic random number generator.
See random for more details.
pub fn try_randomize(&mut self) -> Result<(), Error>
Available on crate feature getrandom only.
pub fn try_randomize(&mut self) -> Result<(), Error>
getrandom only.Tries to fill this [FixedBytes] with the default cryptographic random number
generator.
See random for more details.
pub fn randomize_with<R>(&mut self, rng: &mut R)
Available on crate feature rand only.
pub fn randomize_with<R>(&mut self, rng: &mut R)
rand only.Fills this [FixedBytes] with the given random number generator.
pub fn try_randomize_with<R>(
&mut self,
rng: &mut R,
) -> Result<(), <R as TryRngCore>::Error>where
R: TryRngCore + ?Sized,
Available on crate feature rand only.
pub fn try_randomize_with<R>(
&mut self,
rng: &mut R,
) -> Result<(), <R as TryRngCore>::Error>where
R: TryRngCore + ?Sized,
rand only.Tries to fill this [FixedBytes] with the given random number generator.
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Returns a mutable slice containing the entire array. Equivalent to
&mut s[..].
pub fn covers(&self, other: &FixedBytes<N>) -> bool
pub fn covers(&self, other: &FixedBytes<N>) -> bool
Returns true if all bits set in self are also set in b.
pub fn const_eq(&self, other: &FixedBytes<N>) -> bool
pub fn const_eq(&self, other: &FixedBytes<N>) -> bool
Compile-time equality. NOT constant-time equality.
pub fn const_is_zero(&self) -> bool
pub fn const_is_zero(&self) -> bool
Returns true if no bits are set.
Methods from Deref<Target = [u8; N]>
Sourcepub fn as_ascii(&self) -> Option<&[AsciiChar; N]>
🔬This is a nightly-only experimental API. (ascii_char)
pub fn as_ascii(&self) -> Option<&[AsciiChar; N]>
ascii_char)Converts this array of bytes into an array of ASCII characters,
or returns None if any of the characters is non-ASCII.
Examples
#![feature(ascii_char)]
const HEX_DIGITS: [std::ascii::Char; 16] =
*b"0123456789abcdef".as_ascii().unwrap();
assert_eq!(HEX_DIGITS[1].as_str(), "1");
assert_eq!(HEX_DIGITS[10].as_str(), "a");Sourcepub unsafe fn as_ascii_unchecked(&self) -> &[AsciiChar; N]
🔬This is a nightly-only experimental API. (ascii_char)
pub unsafe fn as_ascii_unchecked(&self) -> &[AsciiChar; N]
ascii_char)Converts this array of bytes into an array of ASCII characters, without checking whether they’re valid.
Safety
Every byte in the array must be in 0..=127, or else this is UB.
1.57.0 · Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice containing the entire array. Equivalent to &s[..].
1.57.0 · Sourcepub fn as_mut_slice(&mut self) -> &mut [T]
pub fn as_mut_slice(&mut self) -> &mut [T]
Returns a mutable slice containing the entire array. Equivalent to
&mut s[..].
1.77.0 · Sourcepub fn each_ref(&self) -> [&T; N]
pub fn each_ref(&self) -> [&T; N]
Borrows each element and returns an array of references with the same
size as self.
Example
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);This method is particularly useful if combined with other methods, like
map. This way, you can avoid moving the original
array if its elements are not Copy.
let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);
// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);1.77.0 · Sourcepub fn each_mut(&mut self) -> [&mut T; N]
pub fn each_mut(&mut self) -> [&mut T; N]
Borrows each element mutably and returns an array of mutable references
with the same size as self.
Example
let mut floats = [3.1, 2.7, -1.0];
let float_refs: [&mut f64; 3] = floats.each_mut();
*float_refs[0] = 0.0;
assert_eq!(float_refs, [&mut 0.0, &mut 2.7, &mut -1.0]);
assert_eq!(floats, [0.0, 2.7, -1.0]);Sourcepub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
split_array)Divides one array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.split_array_ref::<0>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<2>();
assert_eq!(left, &[1, 2]);
assert_eq!(right, &[3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<6>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}Sourcepub fn split_array_mut<const M: usize>(&mut self) -> (&mut [T; M], &mut [T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_mut<const M: usize>(&mut self) -> (&mut [T; M], &mut [T])
split_array)Divides one mutable array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let mut v = [1, 0, 3, 0, 5, 6];
let (left, right) = v.split_array_mut::<2>();
assert_eq!(left, &mut [1, 0][..]);
assert_eq!(right, &mut [3, 0, 5, 6]);
left[1] = 2;
right[1] = 4;
assert_eq!(v, [1, 2, 3, 4, 5, 6]);Sourcepub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
split_array)Divides one array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.rsplit_array_ref::<0>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}
{
let (left, right) = v.rsplit_array_ref::<2>();
assert_eq!(left, &[1, 2, 3, 4]);
assert_eq!(right, &[5, 6]);
}
{
let (left, right) = v.rsplit_array_ref::<6>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}Sourcepub fn rsplit_array_mut<const M: usize>(&mut self) -> (&mut [T], &mut [T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_mut<const M: usize>(&mut self) -> (&mut [T], &mut [T; M])
split_array)Divides one mutable array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let mut v = [1, 0, 3, 0, 5, 6];
let (left, right) = v.rsplit_array_mut::<4>();
assert_eq!(left, &mut [1, 0]);
assert_eq!(right, &mut [3, 0, 5, 6][..]);
left[1] = 2;
right[1] = 4;
assert_eq!(v, [1, 2, 3, 4, 5, 6]);Trait Implementations
Sourceimpl<'a> Arbitrary<'a> for PartialValidatorKey
impl<'a> Arbitrary<'a> for PartialValidatorKey
Sourcefn arbitrary(u: &mut Unstructured<'a>) -> Result<PartialValidatorKey, Error>
fn arbitrary(u: &mut Unstructured<'a>) -> Result<PartialValidatorKey, Error>
Self from the given unstructured data. Read moreSourcefn arbitrary_take_rest(
u: Unstructured<'a>,
) -> Result<PartialValidatorKey, Error>
fn arbitrary_take_rest( u: Unstructured<'a>, ) -> Result<PartialValidatorKey, Error>
Self from the entirety of the given
unstructured data. Read moreSourceimpl Arbitrary for PartialValidatorKey
impl Arbitrary for PartialValidatorKey
Sourcetype Parameters = <FixedBytes<15> as Arbitrary>::Parameters
type Parameters = <FixedBytes<15> as Arbitrary>::Parameters
arbitrary_with accepts for configuration
of the generated Strategy. Parameters must implement Default.Sourcetype Strategy = Map<<FixedBytes<15> as Arbitrary>::Strategy, fn(FixedBytes<15>) -> PartialValidatorKey>
type Strategy = Map<<FixedBytes<15> as Arbitrary>::Strategy, fn(FixedBytes<15>) -> PartialValidatorKey>
Strategy used to generate values of type Self.Sourcefn arbitrary() -> <PartialValidatorKey as Arbitrary>::Strategy
fn arbitrary() -> <PartialValidatorKey as Arbitrary>::Strategy
Sourcefn arbitrary_with(
args: <PartialValidatorKey as Arbitrary>::Parameters,
) -> <PartialValidatorKey as Arbitrary>::Strategy
fn arbitrary_with( args: <PartialValidatorKey as Arbitrary>::Parameters, ) -> <PartialValidatorKey as Arbitrary>::Strategy
Sourceimpl AsMut<[u8]> for PartialValidatorKey
impl AsMut<[u8]> for PartialValidatorKey
Sourceimpl AsMut<FixedBytes<15>> for PartialValidatorKey
impl AsMut<FixedBytes<15>> for PartialValidatorKey
Sourceimpl AsRef<[u8]> for PartialValidatorKey
impl AsRef<[u8]> for PartialValidatorKey
Sourceimpl AsRef<FixedBytes<15>> for PartialValidatorKey
impl AsRef<FixedBytes<15>> for PartialValidatorKey
Sourceimpl BitAnd<&PartialValidatorKey> for PartialValidatorKey
impl BitAnd<&PartialValidatorKey> for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
& operator.Sourcefn bitand(self, rhs: &PartialValidatorKey) -> PartialValidatorKey
fn bitand(self, rhs: &PartialValidatorKey) -> PartialValidatorKey
& operation. Read moreSourceimpl BitAnd for PartialValidatorKey
impl BitAnd for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
& operator.Sourcefn bitand(
self,
__rhs: PartialValidatorKey,
) -> <PartialValidatorKey as BitAnd>::Output
fn bitand( self, __rhs: PartialValidatorKey, ) -> <PartialValidatorKey as BitAnd>::Output
& operation. Read moreSourceimpl BitAndAssign<&PartialValidatorKey> for PartialValidatorKey
impl BitAndAssign<&PartialValidatorKey> for PartialValidatorKey
Sourcefn bitand_assign(&mut self, rhs: &PartialValidatorKey)
fn bitand_assign(&mut self, rhs: &PartialValidatorKey)
&= operation. Read moreSourceimpl BitAndAssign for PartialValidatorKey
impl BitAndAssign for PartialValidatorKey
Sourcefn bitand_assign(&mut self, __rhs: PartialValidatorKey)
fn bitand_assign(&mut self, __rhs: PartialValidatorKey)
&= operation. Read moreSourceimpl BitOr<&PartialValidatorKey> for PartialValidatorKey
impl BitOr<&PartialValidatorKey> for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
| operator.Sourcefn bitor(self, rhs: &PartialValidatorKey) -> PartialValidatorKey
fn bitor(self, rhs: &PartialValidatorKey) -> PartialValidatorKey
| operation. Read moreSourceimpl BitOr for PartialValidatorKey
impl BitOr for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
| operator.Sourcefn bitor(
self,
__rhs: PartialValidatorKey,
) -> <PartialValidatorKey as BitOr>::Output
fn bitor( self, __rhs: PartialValidatorKey, ) -> <PartialValidatorKey as BitOr>::Output
| operation. Read moreSourceimpl BitOrAssign<&PartialValidatorKey> for PartialValidatorKey
impl BitOrAssign<&PartialValidatorKey> for PartialValidatorKey
Sourcefn bitor_assign(&mut self, rhs: &PartialValidatorKey)
fn bitor_assign(&mut self, rhs: &PartialValidatorKey)
|= operation. Read moreSourceimpl BitOrAssign for PartialValidatorKey
impl BitOrAssign for PartialValidatorKey
Sourcefn bitor_assign(&mut self, __rhs: PartialValidatorKey)
fn bitor_assign(&mut self, __rhs: PartialValidatorKey)
|= operation. Read moreSourceimpl BitXor<&PartialValidatorKey> for PartialValidatorKey
impl BitXor<&PartialValidatorKey> for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
^ operator.Sourcefn bitxor(self, rhs: &PartialValidatorKey) -> PartialValidatorKey
fn bitxor(self, rhs: &PartialValidatorKey) -> PartialValidatorKey
^ operation. Read moreSourceimpl BitXor for PartialValidatorKey
impl BitXor for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
^ operator.Sourcefn bitxor(
self,
__rhs: PartialValidatorKey,
) -> <PartialValidatorKey as BitXor>::Output
fn bitxor( self, __rhs: PartialValidatorKey, ) -> <PartialValidatorKey as BitXor>::Output
^ operation. Read moreSourceimpl BitXorAssign<&PartialValidatorKey> for PartialValidatorKey
impl BitXorAssign<&PartialValidatorKey> for PartialValidatorKey
Sourcefn bitxor_assign(&mut self, rhs: &PartialValidatorKey)
fn bitxor_assign(&mut self, rhs: &PartialValidatorKey)
^= operation. Read moreSourceimpl BitXorAssign for PartialValidatorKey
impl BitXorAssign for PartialValidatorKey
Sourcefn bitxor_assign(&mut self, __rhs: PartialValidatorKey)
fn bitxor_assign(&mut self, __rhs: PartialValidatorKey)
^= operation. Read moreSourceimpl Borrow<[u8]> for &PartialValidatorKey
impl Borrow<[u8]> for &PartialValidatorKey
Sourceimpl Borrow<[u8]> for &mut PartialValidatorKey
impl Borrow<[u8]> for &mut PartialValidatorKey
Sourceimpl Borrow<[u8]> for PartialValidatorKey
impl Borrow<[u8]> for PartialValidatorKey
Sourceimpl BorrowMut<[u8]> for &mut PartialValidatorKey
impl BorrowMut<[u8]> for &mut PartialValidatorKey
Sourceimpl BorrowMut<[u8]> for PartialValidatorKey
impl BorrowMut<[u8]> for PartialValidatorKey
Sourceimpl Clone for PartialValidatorKey
impl Clone for PartialValidatorKey
Sourcefn clone(&self) -> PartialValidatorKey
fn clone(&self) -> PartialValidatorKey
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PartialValidatorKey
impl Debug for PartialValidatorKey
Sourceimpl Decodable for PartialValidatorKey
impl Decodable for PartialValidatorKey
Sourceimpl Default for PartialValidatorKey
impl Default for PartialValidatorKey
Sourcefn default() -> PartialValidatorKey
fn default() -> PartialValidatorKey
Sourceimpl Deref for PartialValidatorKey
impl Deref for PartialValidatorKey
Sourceimpl DerefMut for PartialValidatorKey
impl DerefMut for PartialValidatorKey
Sourceimpl<'de> Deserialize<'de> for PartialValidatorKey
impl<'de> Deserialize<'de> for PartialValidatorKey
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<PartialValidatorKey, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<PartialValidatorKey, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl Display for PartialValidatorKey
impl Display for PartialValidatorKey
Sourceimpl Encodable for PartialValidatorKey
impl Encodable for PartialValidatorKey
Sourceimpl From<FixedBytes<15>> for PartialValidatorKey
impl From<FixedBytes<15>> for PartialValidatorKey
Sourcefn from(value: FixedBytes<15>) -> PartialValidatorKey
fn from(value: FixedBytes<15>) -> PartialValidatorKey
Sourceimpl From<PartialValidatorKey> for FixedBytes<15>
impl From<PartialValidatorKey> for FixedBytes<15>
Sourcefn from(value: PartialValidatorKey) -> FixedBytes<15>
fn from(value: PartialValidatorKey) -> FixedBytes<15>
Sourceimpl FromHex for PartialValidatorKey
impl FromHex for PartialValidatorKey
Sourcefn from_hex<T>(
hex: T,
) -> Result<PartialValidatorKey, <PartialValidatorKey as FromHex>::Error>
fn from_hex<T>( hex: T, ) -> Result<PartialValidatorKey, <PartialValidatorKey as FromHex>::Error>
Self from the given hex string, or fails
with a custom error type. Read moreSourceimpl FromStr for PartialValidatorKey
impl FromStr for PartialValidatorKey
Sourceimpl Hash for PartialValidatorKey
impl Hash for PartialValidatorKey
Sourceimpl<__IdxT> Index<__IdxT> for PartialValidatorKeywhere
FixedBytes<15>: Index<__IdxT>,
impl<__IdxT> Index<__IdxT> for PartialValidatorKeywhere
FixedBytes<15>: Index<__IdxT>,
Sourceimpl<__IdxT> IndexMut<__IdxT> for PartialValidatorKeywhere
FixedBytes<15>: IndexMut<__IdxT>,
impl<__IdxT> IndexMut<__IdxT> for PartialValidatorKeywhere
FixedBytes<15>: IndexMut<__IdxT>,
Sourceimpl<'__deriveMoreLifetime> IntoIterator for &'__deriveMoreLifetime PartialValidatorKeywhere
&'__deriveMoreLifetime FixedBytes<15>: IntoIterator,
impl<'__deriveMoreLifetime> IntoIterator for &'__deriveMoreLifetime PartialValidatorKeywhere
&'__deriveMoreLifetime FixedBytes<15>: IntoIterator,
Sourcetype Item = <&'__deriveMoreLifetime FixedBytes<15> as IntoIterator>::Item
type Item = <&'__deriveMoreLifetime FixedBytes<15> as IntoIterator>::Item
Sourcetype IntoIter = <&'__deriveMoreLifetime FixedBytes<15> as IntoIterator>::IntoIter
type IntoIter = <&'__deriveMoreLifetime FixedBytes<15> as IntoIterator>::IntoIter
Sourcefn into_iter(
self,
) -> <&'__deriveMoreLifetime PartialValidatorKey as IntoIterator>::IntoIter
fn into_iter( self, ) -> <&'__deriveMoreLifetime PartialValidatorKey as IntoIterator>::IntoIter
Sourceimpl<'__deriveMoreLifetime> IntoIterator for &'__deriveMoreLifetime mut PartialValidatorKeywhere
&'__deriveMoreLifetime mut FixedBytes<15>: IntoIterator,
impl<'__deriveMoreLifetime> IntoIterator for &'__deriveMoreLifetime mut PartialValidatorKeywhere
&'__deriveMoreLifetime mut FixedBytes<15>: IntoIterator,
Sourcetype Item = <&'__deriveMoreLifetime mut FixedBytes<15> as IntoIterator>::Item
type Item = <&'__deriveMoreLifetime mut FixedBytes<15> as IntoIterator>::Item
Sourcetype IntoIter = <&'__deriveMoreLifetime mut FixedBytes<15> as IntoIterator>::IntoIter
type IntoIter = <&'__deriveMoreLifetime mut FixedBytes<15> as IntoIterator>::IntoIter
Sourcefn into_iter(
self,
) -> <&'__deriveMoreLifetime mut PartialValidatorKey as IntoIterator>::IntoIter
fn into_iter( self, ) -> <&'__deriveMoreLifetime mut PartialValidatorKey as IntoIterator>::IntoIter
Sourceimpl IntoIterator for PartialValidatorKeywhere
FixedBytes<15>: IntoIterator,
impl IntoIterator for PartialValidatorKeywhere
FixedBytes<15>: IntoIterator,
Sourcetype Item = <FixedBytes<15> as IntoIterator>::Item
type Item = <FixedBytes<15> as IntoIterator>::Item
Sourcetype IntoIter = <FixedBytes<15> as IntoIterator>::IntoIter
type IntoIter = <FixedBytes<15> as IntoIterator>::IntoIter
Sourcefn into_iter(self) -> <PartialValidatorKey as IntoIterator>::IntoIter
fn into_iter(self) -> <PartialValidatorKey as IntoIterator>::IntoIter
Sourceimpl LowerHex for PartialValidatorKey
impl LowerHex for PartialValidatorKey
Sourceimpl Not for PartialValidatorKey
impl Not for PartialValidatorKey
Sourcetype Output = PartialValidatorKey
type Output = PartialValidatorKey
! operator.Sourcefn not(self) -> PartialValidatorKey
fn not(self) -> PartialValidatorKey
! operation. Read moreSourceimpl Ord for PartialValidatorKey
impl Ord for PartialValidatorKey
Sourcefn cmp(&self, other: &PartialValidatorKey) -> Ordering
fn cmp(&self, other: &PartialValidatorKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq<&[u8]> for PartialValidatorKey
impl PartialEq<&[u8]> for PartialValidatorKey
Sourceimpl PartialEq<&PartialValidatorKey> for [u8]
impl PartialEq<&PartialValidatorKey> for [u8]
Sourceimpl PartialEq<[u8]> for &PartialValidatorKey
impl PartialEq<[u8]> for &PartialValidatorKey
Sourceimpl PartialEq<[u8]> for PartialValidatorKey
impl PartialEq<[u8]> for PartialValidatorKey
Sourceimpl PartialEq<PartialValidatorKey> for &[u8]
impl PartialEq<PartialValidatorKey> for &[u8]
Sourceimpl PartialEq<PartialValidatorKey> for [u8]
impl PartialEq<PartialValidatorKey> for [u8]
Sourceimpl PartialEq for PartialValidatorKey
impl PartialEq for PartialValidatorKey
Sourceimpl PartialOrd<&[u8]> for PartialValidatorKey
impl PartialOrd<&[u8]> for PartialValidatorKey
Sourceimpl PartialOrd<&PartialValidatorKey> for [u8]
impl PartialOrd<&PartialValidatorKey> for [u8]
Sourceimpl PartialOrd<[u8]> for &PartialValidatorKey
impl PartialOrd<[u8]> for &PartialValidatorKey
Sourceimpl PartialOrd<[u8]> for PartialValidatorKey
impl PartialOrd<[u8]> for PartialValidatorKey
Sourceimpl PartialOrd<PartialValidatorKey> for &[u8]
impl PartialOrd<PartialValidatorKey> for &[u8]
Sourceimpl PartialOrd<PartialValidatorKey> for [u8]
impl PartialOrd<PartialValidatorKey> for [u8]
Sourceimpl PartialOrd for PartialValidatorKey
impl PartialOrd for PartialValidatorKey
Sourceimpl Serialize for PartialValidatorKey
impl Serialize for PartialValidatorKey
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl<'a> TryFrom<&'a [u8]> for &'a PartialValidatorKey
impl<'a> TryFrom<&'a [u8]> for &'a PartialValidatorKey
Sourcetype Error = TryFromSliceError
type Error = TryFromSliceError
Sourcefn try_from(
slice: &'a [u8],
) -> Result<&'a PartialValidatorKey, <&'a PartialValidatorKey as TryFrom<&'a [u8]>>::Error>
fn try_from( slice: &'a [u8], ) -> Result<&'a PartialValidatorKey, <&'a PartialValidatorKey as TryFrom<&'a [u8]>>::Error>
Sourceimpl TryFrom<&[u8]> for PartialValidatorKey
impl TryFrom<&[u8]> for PartialValidatorKey
Sourcetype Error = TryFromSliceError
type Error = TryFromSliceError
Sourcefn try_from(
slice: &[u8],
) -> Result<PartialValidatorKey, <PartialValidatorKey as TryFrom<&[u8]>>::Error>
fn try_from( slice: &[u8], ) -> Result<PartialValidatorKey, <PartialValidatorKey as TryFrom<&[u8]>>::Error>
Sourceimpl<'a> TryFrom<&'a mut [u8]> for &'a mut PartialValidatorKey
impl<'a> TryFrom<&'a mut [u8]> for &'a mut PartialValidatorKey
Sourcetype Error = TryFromSliceError
type Error = TryFromSliceError
Sourcefn try_from(
slice: &'a mut [u8],
) -> Result<&'a mut PartialValidatorKey, <&'a mut PartialValidatorKey as TryFrom<&'a mut [u8]>>::Error>
fn try_from( slice: &'a mut [u8], ) -> Result<&'a mut PartialValidatorKey, <&'a mut PartialValidatorKey as TryFrom<&'a mut [u8]>>::Error>
Sourceimpl TryFrom<&mut [u8]> for PartialValidatorKey
impl TryFrom<&mut [u8]> for PartialValidatorKey
Sourcetype Error = TryFromSliceError
type Error = TryFromSliceError
Sourcefn try_from(
slice: &mut [u8],
) -> Result<PartialValidatorKey, <PartialValidatorKey as TryFrom<&mut [u8]>>::Error>
fn try_from( slice: &mut [u8], ) -> Result<PartialValidatorKey, <PartialValidatorKey as TryFrom<&mut [u8]>>::Error>
Sourceimpl UpperHex for PartialValidatorKey
impl UpperHex for PartialValidatorKey
impl Copy for PartialValidatorKey
impl Eq for PartialValidatorKey
impl MaxEncodedLen<tempo_primitives::::subblock::{impl#100}::{constant#0}> for PartialValidatorKey
impl StructuralPartialEq for PartialValidatorKey